@@ -2,4 +2,4 @@ from string import Template
 
 
 class AutoAlbumentTemplate(Template):
-    delimiter = "@"
+    delimiter = "@@"
